@@ -14,4 +14,10 @@ def colorprint(text,color_name):
     color_print.Color.output_color.cprint_name(text,color_name)
 
 def codecprint(text,color_name):
-    color_print.Color.output_color.color_print(text,color_name)
\ No newline at end of file
+    color_print.Color.output_color.color_print(text,color_name)
+
+def setcolor_name(color_name):
+    color_print.Color.output_color.setcolor(color_name)
+
+def resetcolor():
+    color_print.Color.output_color.resetcolor()
